@@ -21,7 +21,7 @@
 #define __BISHO_WINDOW_H__
 
 #include <gtk/gtk.h>
-#include "mux-window.h"
+#include <mojito-client/mojito-client.h>
 #include "service-info.h"
 
 G_BEGIN_DECLS
@@ -52,22 +52,22 @@ typedef struct _BishoWindow      BishoWindow;
 typedef struct _BishoWindowClass BishoWindowClass;
 
 struct _BishoWindow {
-  MuxWindow parent;
+  GtkWindow parent;
   BishoWindowPrivate *priv;
 };
 
 struct _BishoWindowClass {
-  MuxWindowClass parent_class;
+  GtkWindowClass parent_class;
 };
 
 GType bisho_window_get_type (void) G_GNUC_CONST;
 
 GtkWidget * bisho_window_new (void);
 
-void bisho_window_change_banner (BishoWindow *window, ServiceInfo *info);
-
 void bisho_window_callback (BishoWindow *window, const char *id, GHashTable *params);
 
+MojitoClient * bisho_window_get_mojito (BishoWindow *window);
+
 G_END_DECLS
 
 #endif /* __BISHO_WINDOW_H__ */
